#!/usr/bin/env python
# -*- coding: utf-8 -*-
from __future__ import unicode_literals


__version_info__ = (0, 0, 2)
__version__ = '.'.join([unicode(i) for i in __version_info__])

__author__ = 'David Vuong'
__author_email__ = 'david@imageintelligence.com'
